netapp_ontap.models.san_application_components API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.san_application_components`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SanApplicationComponentsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SanApplicationComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `igroup_name GET POST PATCH`

    The name of the initiator group through which the contents of this application will be accessed. Modification of this parameter is a disruptive operation. All LUNs in the application component will be unmapped from the current igroup and re-mapped to the new igroup.

  `lun_count GET POST PATCH`

    The number of LUNs in the application component.

  `name GET POST PATCH`

    The name of the application component.

  `os_type GET POST PATCH`

    The name of the host OS running the application.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - netware
    - openvms
    - solaris
    - solaris_efi
    - vmware
    - windows
    - windows_2008
    - windows_gpt
    - xen
  `qos GET POST`

    The qos field of the san_application_components.

  `storage_service GET POST PATCH`

    The storage_service field of the san_application_components.

  `tiering GET POST PATCH`

    The tiering field of the san_application_components.

  `total_size GET POST PATCH`

    The total size of the application component, split across the member LUNs. Usage: {<integer>[KB|MB|GB|TB|PB]}